/*
    =========================================================================
	File:		Dep.java
	Author:		Warren Pfeffer
	Contact:	slinky@njcc.com
    =========================================================================
    Copyright (C) 1997  Warren Pfeffer

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program (see COPYING-2.0.gz); if not, write to:

		Free Software Foundation, Inc.
		59 Temple Place, Suite 330
		Boston, MA  02111-1307  USA
    =========================================================================
*/
package WARREN.tools;

public class Dep {

	static final int	UNRESOLVED = 0;
	static final int	RESOLVED = 1;
	static final int	IGNORE = 2;

	private String	name_;
	private Type	type_;
	private int		state_;

	public Dep(String name)
	{
		Resolve(name);
	}

	public Dep(Type type)
	{
		name_ = type.SfxdName();
		type_ = type;
		state_ = UNRESOLVED;
	}

	public final void Resolve(String name)
	{
		name_ = name;
		type_ = null;
		state_ = RESOLVED;
	}

	public final int State()
		{return state_;}

	public final void SetState(int state)
		{state_ = state;}

	public final String Name()
		{return name_;}

	public final String NoSfxName(String sfx)
	{
		String no_sfx_name = null;

		int si = name_.lastIndexOf(sfx);

		if(si > 0)
		{
			no_sfx_name = name_.substring(0, si);
		}
		else
		{
			no_sfx_name = name_;
		}

		return no_sfx_name;
	}

	public final Type GetType()
		{return type_;}

	public int hashCode()
		{return name_.hashCode();}

	public String toString()
		{return name_;}

	public boolean equals(Object obj)
		{return name_.equals(obj.toString());}
}
