/*
    =========================================================================
	File:		JDSystem.java
	Author:		Warren Pfeffer
	Contact:	slinky@njcc.com
    =========================================================================
    Copyright (C) 1997  Warren Pfeffer

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program (see COPYING-2.0.gz); if not, write to:

		Free Software Foundation, Inc.
		59 Temple Place, Suite 330
		Boston, MA  02111-1307  USA
    =========================================================================
*/
package WARREN.tools;

import java.io.PrintWriter;
import java.io.FileOutputStream;
import java.io.IOException;

class JDSystem {

	public static class Props extends GetProps {
		public boolean silent;
		public String outstream;
		public String errstream;
		public String profstream;
		public String dbugstream;
		public String makestream;
	}
	private static Props $ = new Props();

	private static boolean inited_ = false;
	private static PrintWriter pw_out_ = null;
	private static PrintWriter pw_err_ = null;
	private static PrintWriter pw_prof_ = null;
	private static PrintWriter pw_dbug_ = null;
	private static PrintWriter pw_make_ = null;

	private boolean silent_;

	private boolean Init()
	{
		boolean rc = true;

		if(!inited_)
		{
			inited_ = true;

			silent_ = $.silent;

			try
			{
				if($.outstream.length() > 0)
					pw_out_ =
						new PrintWriter(new FileOutputStream($.outstream), true);
				else
					pw_out_ = new PrintWriter(System.out, true);

				if($.errstream.length() > 0)
					pw_err_ =
						new PrintWriter(new FileOutputStream($.errstream), true);
				else
					pw_err_ = new PrintWriter(System.err, true);

				if(!silent_)
				{
					if($.profstream.length() > 0)
						pw_prof_ =
							new PrintWriter(new FileOutputStream($.profstream), true);
					else
						pw_prof_ = pw_err_;

					if($.dbugstream.length() > 0)
						pw_dbug_ =
							new PrintWriter(new FileOutputStream($.dbugstream), true);
					else
						pw_dbug_ = pw_err_; 

					if($.makestream.length() > 0)
						pw_make_ =
							new PrintWriter(new FileOutputStream($.makestream), true);
					else
						pw_make_ = pw_out_;
				}
			}
			catch(Exception e)
			{
				rc = false;
				System.err.println(e);
			}
		}

		return rc;
	}

	protected JDSystem()
	{
		Init();
	}

	protected void PrintOut(Object obj)
		{pw_out_.print(obj); pw_out_.flush();}

	protected void PrintOutln(Object obj)
		{pw_out_.println(obj);}

	protected void PrintErr(Object obj)
		{pw_err_.print(obj); pw_err_.flush();}

	protected void PrintErrln(Object obj)
		{pw_err_.println(obj);}

	protected void PrintProf(Object obj)
		{if(!silent_) {pw_prof_.print(obj); pw_prof_.flush();}}

	protected void PrintProfln(Object obj)
		{if(!silent_) pw_prof_.println(obj);}

	protected void PrintDbug(Object obj)
		{if(!silent_) {pw_dbug_.print(obj); pw_dbug_.flush();}}

	protected void PrintDbugln(Object obj)
		{if(!silent_) pw_dbug_.println(obj);}

	protected void PrintMake(Object obj)
		{if(!silent_) {pw_make_.print(obj); pw_make_.flush();}}

	protected void PrintMakeln(Object obj)
		{if(!silent_) pw_make_.println(obj);}

	protected PrintWriter OutWriter()
		{return pw_out_;}

	protected PrintWriter ErrWriter()
		{return pw_err_;}

	protected PrintWriter ProfWriter()
		{return pw_prof_;}

	protected PrintWriter DbugWriter()
		{return pw_dbug_;}

	protected PrintWriter MakeWriter()
		{return pw_make_;}
}
