/*
    =========================================================================
	File:		Type.java
	Author:		Warren Pfeffer
	Contact:	slinky@njcc.com
    =========================================================================
    Copyright (C) 1997  Warren Pfeffer

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program (see COPYING-2.0.gz); if not, write to:

		Free Software Foundation, Inc.
		59 Temple Place, Suite 330
		Boston, MA  02111-1307  USA
    =========================================================================
*/
package WARREN.tools;

public class Type extends SrcSymbol {

	private String	sfxd_name_;
	private String	name_;
	private String	sfx_;
	private String	context_;
	private boolean	is_pri_pfx_;
	private String	base_cls_;

	public Type(String sfxd_name, String context, String base_cls, String file_name, int lno)
	{
		super("", file_name, lno);
		SetSfxdName(sfxd_name);
		SetContext(context);
		SetBaseCls(base_cls);
	}

	public Type()
	{
		this("", "", "", "", 0);
	}

	public final void SetSfxdName(String sfxd_name)
	{
		sfxd_name_ = sfxd_name; 
		int di = sfxd_name_.lastIndexOf('.');
		SetSymbolName(name_ = sfxd_name_.substring(0, di));
		sfx_ = sfxd_name_.substring(di+1);
	}

	public final void SetContext(String context)
	{
		context_ = context;
		is_pri_pfx_ = context_.equals("PrimaryPrefix");
	}

	public final void SetBaseCls(String base_cls)
		{base_cls_ = base_cls;}

	public final String SfxdName()
		{return sfxd_name_;}

	public final String Name()
		{return name_;}

	public final String Sfx()
		{return sfx_;}

	public final String Context()
		{return context_;}

	public final String BaseCls()
		{return base_cls_;}

	public final boolean IsPriPfx()
		{return is_pri_pfx_;}

	public int hashCode()
		{return sfxd_name_.hashCode();}

	public String toString()
		{return sfxd_name_;}

	public boolean equals(Object obj)
		{return sfxd_name_.equals(obj.toString());}

	public String Dump()
	{
		return (
			"type="+sfxd_name_
			+", context="+context_
			+", base_cls="+base_cls_
			+", file="+FileName()
			+", lno="+LineNum()
			);
	}
}
