/*
    =========================================================================
	File:		ZippedDir.java
	Author:		Warren Pfeffer
	Contact:	slinky@njcc.com
    =========================================================================
    Copyright (C) 1997  Warren Pfeffer

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program (see COPYING-2.0.gz); if not, write to:

		Free Software Foundation, Inc.
		59 Temple Place, Suite 330
		Boston, MA  02111-1307  USA
    =========================================================================
*/
package WARREN.tools;

import java.io.*;
import java.util.*;
import java.util.zip.*;

//------------------------------------------

class ZippedDir {

	private String	zip_full_pth_;
	private String	zip_dir_pth_;
	private String	pkg_sub_pth_;
	private String	pkg_sub_pth_unix_;
	private Vector	zipped_class_files_;

	public String ArchiveFullPth()
		{return zip_full_pth_;}

	public String ArchiveDirPth()
		{return zip_dir_pth_;}

	public Enumeration Classes()
		{return zipped_class_files_.elements();}

	public ZippedDir(String zip_file_name, String pkg_sub_pth)
		throws IOException
	{
		this(new HashableZipFile(zip_file_name), pkg_sub_pth);
	}

	public ZippedDir(HashableZipFile hz, String pkg_sub_pth)
		throws IOException
	{
		String	file_sep = System.getProperty("file.separator");

		zip_full_pth_ = hz.getName();

		zip_dir_pth_ =	zip_full_pth_
					.substring(0, zip_full_pth_.lastIndexOf(file_sep)+1);

		pkg_sub_pth_ = 
			pkg_sub_pth.endsWith(file_sep) ?
				pkg_sub_pth : pkg_sub_pth+file_sep;

		pkg_sub_pth_unix_ = pkg_sub_pth_.replace(file_sep.charAt(0), '/');

		zipped_class_files_ = new Vector();


		if(hz.getEntry(pkg_sub_pth_unix_) == null)
			throw new IOException(pkg_sub_pth_+" not found");

		ZipEntry ze = null;

		for(
			Enumeration itr = hz.entries();
			itr.hasMoreElements();
			)
		{
			ze = (ZipEntry)itr.nextElement();

			String en = ze.getName();

			if(
				en.startsWith(pkg_sub_pth_unix_)
				&&
				en.endsWith(".class")
				)
			{
				zipped_class_files_.addElement(
						en.substring(en.lastIndexOf("/")+1)
					);
			}
		}
	}

	public static void main(String args[])
	{
		try
		{
			ZippedDir zd = new ZippedDir(args[0], args[1]);

			System.out.println("archive="+zd.ArchiveFullPth());
			System.out.println("dir="+zd.ArchiveDirPth());
			System.out.println("classes=");

			for(
				Enumeration itr = zd.Classes();
				itr.hasMoreElements();
				)
			{
				System.out.println((String)itr.nextElement());
			}
		}
		catch(Exception e)
		{
			System.err.println(e);
		}
	}
}
